@@ -1,6 +1,6 @@
 /*= -*- c-basic-offset: 4; indent-tabs-mode: nil; -*-
  * rproxy -- dynamic caching and delta update in HTTP
- * $Id: hex.c,v 1.17 2001/03/18 14:42:28 mbp Exp $
+ * $Id: hex.c,v 1.19 2003/06/12 05:47:22 wayned Exp $
  * 
  * Copyright (C) 2000, 2001 by Martin Pool <mbp@samba.org>
  * 
@@ -23,11 +23,13 @@
 
 #include <assert.h>
 #include <sys/types.h>
+#ifdef HAVE_INTTYPES_H
 #include <inttypes.h>
+#endif
 #include <stdlib.h>
 #include <stdio.h>
 
-#include "rsync.h"
+#include "librsync.h"
 
 
 void
