@@ -1,10 +1,11 @@
 /*= -*- c-basic-offset: 4; indent-tabs-mode: nil; -*-
  *
  * librsync -- the library for network deltas
- * $Id: mdfour.c,v 1.31 2003/06/12 05:47:22 wayned Exp $
+ * $Id: mdfour.c,v 1.36 2004/09/10 02:07:12 mbp Exp $
  * 
  * Copyright (C) 2000, 2001 by Martin Pool <mbp@samba.org>
  * Copyright (C) 1997-1999 by Andrew Tridgell
+ * Copyright (C) 2002, 2003 by Donovan Baarda <abo@minkirri.apana.org.au> 
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -34,6 +35,10 @@
  * 
  * 2002-06-27: Donovan Baarda <abo@minkirri.apana.org.au>
  *   further optimisations and cleanups.
+ *
+ * 2004-09-09: Simon Law  <sfllaw@debian.org>
+ *   handle little-endian machines that can't do unaligned access
+ *   (e.g. ia64, pa-risc).
  */
 
 #include <config.h>
@@ -65,6 +70,11 @@ static unsigned char PADDING[64] = {
 };
 
 
+static void
+rs_mdfour_block(rs_mdfour_t *md, void const *p);
+
+
+
 /**
  * Update an MD4 accumulator from a 64-byte chunk.
  *
@@ -165,7 +175,7 @@ rs_mdfour64(rs_mdfour_t * m, const void *p)
  * There are some nice endianness routines in glib, including assembler
  * variants. If we ever depended on glib, then it could be good to use them
  * instead. */
-static void
+inline static void
 copy4( /* @out@ */ unsigned char *out, uint32_t const x)
 {
     out[0] = x;
@@ -178,7 +188,7 @@ copy4( /* @out@ */ unsigned char *out, uint32_t const x)
 /* We need this if there is a uint64 */
 /* --robert.weber@Colorado.edu	     */
 #ifdef HAVE_UINT64
-static void
+inline static void
 copy8( /* @out@ */ unsigned char *out, uint64_t const x)
 {
     out[0] = x;
@@ -195,7 +205,7 @@ copy8( /* @out@ */ unsigned char *out, uint64_t const x)
 
 /* We only need this if we are big-endian */
 #ifdef WORDS_BIGENDIAN
-static void
+inline static void
 copy64( /* @out@ */ uint32_t * M, unsigned char const *in)
 {
     int i=16;
@@ -211,7 +221,8 @@ copy64( /* @out@ */ uint32_t * M, unsigned char const *in)
  * Accumulate a block, making appropriate conversions for bigendian
  * machines.
  */
-void rs_mdfour_block(rs_mdfour_t *md, void const *p)
+inline static void
+rs_mdfour_block(rs_mdfour_t *md, void const *p)
 {
     uint32_t        M[16];
 
@@ -221,8 +232,39 @@ void rs_mdfour_block(rs_mdfour_t *md, void const *p)
 
 
 #else /* WORDS_BIGENDIAN */
-/* if we are little endian, we can process directly */
-#define rs_mdfour_block(md,p) rs_mdfour64(md,p)
+
+#  ifdef __i386__
+
+/* If we are on an IA-32 machine, we can process directly. */
+inline static void
+rs_mdfour_block(rs_mdfour_t *md, void const *p)
+{
+    rs_mdfour64(md,p);
+}
+
+#  else /* !WORDS_BIGENDIAN && !__i386__ */
+
+/* We are little-endian, but not on i386 and therefore may not be able
+ * to do unaligned access safely/quickly.
+ *
+ * So if the input is not already aligned correctly, copy it to an
+ * aligned buffer first.  */
+inline static void
+rs_mdfour_block(rs_mdfour_t *md, void const *p)
+{
+    unsigned long ptrval = (unsigned long) p;
+
+    if (ptrval & 3) {
+        uint32_t        M[16];
+        
+        memcpy(M, p, 16 * sizeof(uint32_t));
+        rs_mdfour64(md, M);
+    } else {
+        rs_mdfour64(md, (const uint32_t *) p);
+    }
+}
+
+#  endif /* ! __i386__ */
 #endif /* WORDS_BIGENDIAN */
 
 
