@@ -1,7 +1,7 @@
 /*= -*- c-basic-offset: 4; indent-tabs-mode: nil; -*-
  *
  * librsync -- library for network deltas
- * $Id: mksum.c,v 1.34 2003/06/12 05:47:22 wayned Exp $
+ * $Id: mksum.c,v 1.35 2004/09/10 01:37:56 mbp Exp $
  * 
  * Copyright (C) 1999, 2000, 2001 by Martin Pool <mbp@samba.org>
  * Copyright (C) 1999 by Andrew Tridgell <tridge@samba.org>
@@ -131,7 +131,7 @@ rs_sig_s_generate(rs_job_t *job)
         return result;
     }
 
-    rs_trace("got %d byte block", len);
+    rs_trace("got %ld byte block", (long) len);
 
     return rs_sig_do_block(job, block, len);
 }
