@@ -1,7 +1,7 @@
 /*= -*- c-basic-offset: 4; indent-tabs-mode: nil; -*-
  *
  * librsync -- library for network deltas
- * $Id: netint.c,v 1.26 2003/08/05 08:28:21 abo Exp $
+ * $Id: netint.c,v 1.27 2004/09/10 02:48:58 mbp Exp $
  * 
  * Copyright (C) 1999, 2000, 2001 by Martin Pool <mbp@samba.org>
  * Copyright (C) 1999 by Andrew Tridgell <tridge@samba.org>
@@ -179,6 +179,6 @@ int rs_int_len(rs_long_t val)
     else if (!(val & ~(rs_long_t)0xffffffffffffffff))
         return 8;
     else {
-        rs_fatal("can't encode integer %.0f yet", (double) val);
+        rs_fatal("can't encode integer " PRINTF_FORMAT_U64 " yet", PRINTF_CAST_U64(val));
     }
 }
