@@ -1,7 +1,7 @@
 /*= -*- c-basic-offset: 4; indent-tabs-mode: nil; -*-
  *
  * librsync -- the library for network deltas
- * $Id: patch.c,v 1.29 2003/08/05 08:28:21 abo Exp $
+ * $Id: patch.c,v 1.30 2004/09/10 02:48:58 mbp Exp $
  * 
  * Copyright (C) 2000, 2001 by Martin Pool <mbp@samba.org>
  * 
@@ -68,9 +68,9 @@ static rs_result rs_patch_s_cmdbyte(rs_job_t *job)
 
     job->cmd = &rs_prototab[job->op];
         
-    rs_trace("got command byte 0x%02x (%s), len_1=%.0f", job->op,
+    rs_trace("got command byte 0x%02x (%s), len_1=" PRINTF_FORMAT_U64 "", job->op,
              rs_op_kind_name(job->cmd->kind),
-             (double) job->cmd->len_1);
+             PRINTF_CAST_U64(job->cmd->len_1));
 
     if (job->cmd->len_1)
         job->statefn = rs_patch_s_params;
@@ -150,10 +150,10 @@ static rs_result rs_patch_s_literal(rs_job_t *job)
 {
     rs_long_t   len = job->param1;
     
-    rs_trace("LITERAL(len=%.0f)", (double) len);
+    rs_trace("LITERAL(len=" PRINTF_FORMAT_U64 ")", PRINTF_CAST_U64(len));
 
     if (len < 0) {
-        rs_log(RS_LOG_ERR, "invalid length=%.0f on LITERAL command", (double) len);
+        rs_log(RS_LOG_ERR, "invalid length=" PRINTF_FORMAT_U64 " on LITERAL command", PRINTF_CAST_U64(len));
         return RS_CORRUPT;
     }
 
@@ -177,15 +177,15 @@ static rs_result rs_patch_s_copy(rs_job_t *job)
     where = job->param1;
     len = job->param2;
         
-    rs_trace("COPY(where=%.0f, len=%.0f)", (double) where, (double) len);
+    rs_trace("COPY(where=" PRINTF_FORMAT_U64 ", len=" PRINTF_FORMAT_U64 ")", PRINTF_CAST_U64(where), PRINTF_CAST_U64(len));
 
     if (len < 0) {
-        rs_log(RS_LOG_ERR, "invalid length=%.0f on COPY command", (double) len);
+        rs_log(RS_LOG_ERR, "invalid length=" PRINTF_FORMAT_U64 " on COPY command", PRINTF_CAST_U64(len));
         return RS_CORRUPT;
     }
 
     if (where < 0) {
-        rs_log(RS_LOG_ERR, "invalid where=%.0f on COPY command", (double) where);
+        rs_log(RS_LOG_ERR, "invalid where=" PRINTF_FORMAT_U64 " on COPY command", PRINTF_CAST_U64(where));
         return RS_CORRUPT;
     }
 
@@ -224,8 +224,8 @@ static rs_result rs_patch_s_copying(rs_job_t *job)
     if (!len)
         return RS_BLOCKED;
 
-    rs_trace("copy %.0f bytes from basis at offset %.0f",
-             (double) len, (double) job->basis_pos);
+    rs_trace("copy " PRINTF_FORMAT_U64 " bytes from basis at offset " PRINTF_FORMAT_U64 "",
+             PRINTF_CAST_U64(len), PRINTF_CAST_U64(job->basis_pos));
 
     ptr = buf = rs_alloc(len, "basis buffer");
     
@@ -235,7 +235,7 @@ static rs_result rs_patch_s_copying(rs_job_t *job)
     else
         rs_trace("copy callback returned %s", rs_strerror(result));
     
-    rs_trace("got %.0f bytes back from basis callback", (double) len);
+    rs_trace("got " PRINTF_FORMAT_U64 " bytes back from basis callback", PRINTF_CAST_U64(len));
 
     memcpy(buffs->next_out, ptr, len);
 
