@@ -1,7 +1,7 @@
 /*= -*- c-basic-offset: 4; indent-tabs-mode: nil; -*-
  *
  * librsync -- the library for network deltas
- * $Id: rdiff.c,v 1.37 2003/08/03 14:36:09 abo Exp $
+ * $Id: rdiff.c,v 1.38 2004/09/10 01:37:56 mbp Exp $
  * 
  * Copyright (C) 1999, 2000, 2001 by Martin Pool <mbp@samba.org>
  * 
@@ -181,14 +181,14 @@ static void rdiff_show_version(void)
     printf("rdiff (%s) [%s]\n"
            "Copyright (C) 1997-2001 by Martin Pool, Andrew Tridgell and others.\n"
            "http://rproxy.samba.org/\n"
-           "Capabilities: %d bit files%s%s%s\n"
+           "Capabilities: %ld bit files%s%s%s\n"
            "\n"
            "librsync comes with NO WARRANTY, to the extent permitted by law.\n"
            "You may redistribute copies of librsync under the terms of the GNU\n"
            "Lesser General Public License.  For more information about these\n"
            "matters, see the files named COPYING.\n",
            rs_librsync_version, RS_CANONICAL_HOST,
-           8 * sizeof(rs_long_t), zlib, bzlib, trace);
+           (long) (8 * sizeof(rs_long_t)), zlib, bzlib, trace);
 }
 
 
