@@ -1,7 +1,7 @@
 /*=                    -*- c-basic-offset: 4; indent-tabs-mode: nil; -*-
  *
  * librsync -- the library for network deltas
- * $Id: scoop.c,v 1.26 2003/07/24 09:12:09 abo Exp $
+ * $Id: scoop.c,v 1.28 2004/09/10 02:48:58 mbp Exp $
  * 
  * Copyright (C) 2000, 2001 by Martin Pool <mbp@samba.org>
  * 
@@ -93,8 +93,8 @@ void rs_scoop_input(rs_job_t *job, size_t len)
         if (job->scoop_buf)
             free(job->scoop_buf);
         job->scoop_buf = job->scoop_next = newbuf;
-        rs_trace("resized scoop buffer to %.0f bytes from %.0f",
-                 (double) newsize, (double) job->scoop_alloc);
+        rs_trace("resized scoop buffer to " PRINTF_FORMAT_U64 " bytes from " PRINTF_FORMAT_U64 "",
+                 PRINTF_CAST_U64(newsize), PRINTF_CAST_U64(job->scoop_alloc));
         job->scoop_alloc = newsize;
     } else {
         /* this buffer size is fine, but move the existing
@@ -111,7 +111,7 @@ void rs_scoop_input(rs_job_t *job, size_t len)
     assert(tocopy + job->scoop_avail <= job->scoop_alloc);
 
     memcpy(job->scoop_next + job->scoop_avail, stream->next_in, tocopy);
-    rs_trace("accepted %.0f bytes from input to scoop", (double) tocopy);
+    rs_trace("accepted " PRINTF_FORMAT_U64 " bytes from input to scoop", PRINTF_CAST_U64(tocopy));
     job->scoop_avail += tocopy;
     stream->next_in += tocopy;
     stream->avail_in -= tocopy;
@@ -136,12 +136,12 @@ void rs_scoop_advance(rs_job_t *job, size_t len)
      * at them all at the same time. */
     if (job->scoop_avail) {
         /* reading from the scoop buffer */
-         rs_trace("advance over %d bytes from scoop", len); 
+         rs_trace("advance over %ld bytes from scoop", (long) len); 
         assert(len <= job->scoop_avail);
         job->scoop_avail -= len;
         job->scoop_next += len;
     } else {
-         rs_trace("advance over %d bytes from input buffer", len); 
+         rs_trace("advance over %ld bytes from input buffer", (long) len); 
         assert(len <= stream->avail_in);
         stream->avail_in -= len;
         stream->next_in += len;
@@ -171,7 +171,7 @@ rs_result rs_scoop_readahead(rs_job_t *job, size_t len, void **ptr)
     if (job->scoop_avail >= len) {
         /* We have enough data queued to satisfy the request,
          * so go straight from the scoop buffer. */
-        rs_trace("got %.0f bytes direct from scoop", (double) len);
+        rs_trace("got " PRINTF_FORMAT_U64 " bytes direct from scoop", PRINTF_CAST_U64(len));
         *ptr = job->scoop_next;
         return RS_DONE;
     } else if (job->scoop_avail) {
@@ -181,26 +181,26 @@ rs_result rs_scoop_readahead(rs_job_t *job, size_t len, void **ptr)
         rs_scoop_input(job, len);
 
         if (job->scoop_avail < len) {
-            rs_trace("still have only %.0f bytes in scoop",
-                     (double) job->scoop_avail);
+            rs_trace("still have only " PRINTF_FORMAT_U64 " bytes in scoop",
+                     PRINTF_CAST_U64(job->scoop_avail));
             return RS_BLOCKED;
         } else {
-            rs_trace("scoop now has %.0f bytes, this is enough",
-                     (double) job->scoop_avail);
+            rs_trace("scoop now has " PRINTF_FORMAT_U64 " bytes, this is enough",
+                     PRINTF_CAST_U64(job->scoop_avail));
             *ptr = job->scoop_next;
             return RS_DONE;
         }
     } else if (stream->avail_in >= len) {
         /* There's enough data in the stream's input */
         *ptr = stream->next_in;
-        rs_trace("got %.0f bytes from input buffer", (double) len);
+        rs_trace("got " PRINTF_FORMAT_U64 " bytes from input buffer", PRINTF_CAST_U64(len));
         return RS_DONE;
     } else if (stream->avail_in > 0) {
         /* Nothing was queued before, but we don't have enough
          * data to satisfy the request.  So queue what little
          * we have, and try again next time. */
-        rs_trace("couldn't satisfy request for %.0f, scooping %.0f bytes",
-                 (double) len, (double) job->scoop_avail);
+        rs_trace("couldn't satisfy request for " PRINTF_FORMAT_U64 ", scooping " PRINTF_FORMAT_U64 " bytes",
+                 PRINTF_CAST_U64(len), PRINTF_CAST_U64(job->scoop_avail));
         rs_scoop_input(job, len);
         return RS_BLOCKED;
     } else if (stream->eof_in) {
