@@ -1,6 +1,6 @@
 /*= -*- c-basic-offset: 4; indent-tabs-mode: nil; -*-
  *
- * $Id: stats.c,v 1.33 2003/08/03 14:36:09 abo Exp $
+ * $Id: stats.c,v 1.34 2004/09/10 02:48:58 mbp Exp $
  * 
  * Copyright (C) 2000, 2001 by Martin Pool <mbp@samba.org>
  * 
@@ -85,34 +85,34 @@ rs_format_stats(rs_stats_t const * stats,
 
     if (stats->lit_cmds) {
         len += snprintf(buf+len, size-len,
-                        "literal[%d cmds, %.0f bytes, %.0f cmdbytes] ",
+                        "literal[%d cmds, " PRINTF_FORMAT_U64 " bytes, " PRINTF_FORMAT_U64 " cmdbytes] ",
                         stats->lit_cmds,
-                        (double) stats->lit_bytes,
-                        (double) stats->lit_cmdbytes);
+                        PRINTF_CAST_U64(stats->lit_bytes),
+                        PRINTF_CAST_U64(stats->lit_cmdbytes));
     }
 
     if (stats->sig_cmds) {
         len += snprintf(buf+len, size-len,
-                        "in-place-signature[%.0f cmds, %.0f bytes] ",
-                        (double) stats->sig_cmds,
-                        (double) stats->sig_bytes);
+                        "in-place-signature[" PRINTF_FORMAT_U64 " cmds, " PRINTF_FORMAT_U64 " bytes] ",
+                        PRINTF_CAST_U64(stats->sig_cmds),
+                        PRINTF_CAST_U64(stats->sig_bytes));
     }
 
     if (stats->copy_cmds || stats->false_matches) {
         len += snprintf(buf+len, size-len, 
-                        "copy[%.0f cmds, %.0f bytes, %.0f false, %.0f cmdbytes]",
-                        (double) stats->copy_cmds,
-                        (double) stats->copy_bytes,
-                        (double) stats->false_matches,
-                        (double) stats->copy_cmdbytes);
+                        "copy[" PRINTF_FORMAT_U64 " cmds, " PRINTF_FORMAT_U64 " bytes, " PRINTF_FORMAT_U64 " false, " PRINTF_FORMAT_U64 " cmdbytes]",
+                        PRINTF_CAST_U64(stats->copy_cmds),
+                        PRINTF_CAST_U64(stats->copy_bytes),
+                        PRINTF_CAST_U64(stats->false_matches),
+                        PRINTF_CAST_U64(stats->copy_cmdbytes));
     }
         
 
     if (stats->sig_blocks) {
         len  += snprintf(buf+len, size-len,
-                         "signature[%.0f blocks, %.0f bytes per block]",
-                         (double) stats->sig_blocks,
-                         (double) stats->block_len);
+                         "signature[" PRINTF_FORMAT_U64 " blocks, " PRINTF_FORMAT_U64 " bytes per block]",
+                         PRINTF_CAST_U64(stats->sig_blocks),
+                         PRINTF_CAST_U64(stats->block_len));
     }
     
     return buf;
