@@ -1,7 +1,7 @@
 /*= -*- c-basic-offset: 4; indent-tabs-mode: nil; -*-
  *
  * librsync -- dynamic caching and delta update in HTTP
- * $Id: stream.c,v 1.16 2003/06/12 05:47:23 wayned Exp $
+ * $Id: stream.c,v 1.17 2004/09/10 01:37:56 mbp Exp $
  * 
  * Copyright (C) 2000, 2001 by Martin Pool <mbp@samba.org>
  * 
@@ -116,15 +116,15 @@ int rs_buffers_copy(rs_buffers_t *stream, int max_len)
     assert(len > 0);
 
     if ((unsigned) len > stream->avail_in) {
-        rs_trace("copy limited to %d available input bytes",
-                 stream->avail_in);
+        rs_trace("copy limited to %ld available input bytes",
+                 (long) stream->avail_in);
         len = stream->avail_in;
     }
 
 
     if ((unsigned) len > stream->avail_out) {
-        rs_trace("copy limited to %d available output bytes",
-                 stream->avail_out);
+        rs_trace("copy limited to %ld available output bytes",
+                 (long) stream->avail_out);
         len = stream->avail_out;
     }
 
