@@ -1,7 +1,7 @@
 /*= -*- c-basic-offset: 4; indent-tabs-mode: nil; -*-
  *
  * librsync -- the library for network deltas
- * $Id: types.h,v 1.1 2001/03/18 10:48:08 mbp Exp $
+ * $Id: types.h,v 1.2 2002/06/29 19:47:42 wayned Exp $
  * 
  * Copyright (C) 2001 by Martin Pool <mbp@samba.org>
  * 
@@ -20,17 +20,29 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-
+#define HAVE_UINT64 1 /* assume success, but might be undefined below */
 
 #if defined(HAVE_STDINT_H)
 #  include <stdint.h>
-#elif SIZEOF_UNSIGNED_INT == 4
-#  define uint32_t unsigned int
-#elif SIZEOF_UNSIGNED_LONG == 4
-#  define uint32_t unsigned long
-#elif SIZEOF_UNSIGNED_SHORT == 4
-#  define uint32_t unsigned short
 #else
+# if SIZEOF_UNSIGNED_INT == 4
+#  define uint32_t unsigned int
+# elif SIZEOF_UNSIGNED_LONG == 4
+#  define uint32_t unsigned long
+# elif SIZEOF_UNSIGNED_SHORT == 4
+#  define uint32_t unsigned short
+# else
 #  error "can't find an appropriate 32-bit integer type"
+# endif
+# if SIZEOF_UNSIGNED_INT == 8
+#  define uint64_t unsigned int
+# elif SIZEOF_UNSIGNED_LONG == 8
+#  define uint64_t unsigned long
+# elif SIZEOF_UNSIGNED_SHORT == 8
+#  define uint64_t unsigned short
+# elif SIZEOF_LONG_LONG == 8
+#  define uint64_t unsigned long long
+# else
+#  undef HAVE_UINT64
+# endif
 #endif
-
