@@ -1,7 +1,7 @@
 /*= -*- c-basic-offset: 4; indent-tabs-mode: nil; -*-
  *
  * librsync -- dynamic caching and delta update in HTTP
- * $Id: version.c,v 1.9 2001/03/05 07:09:34 mbp Exp $
+ * $Id: version.c,v 1.10 2003/06/12 05:47:23 wayned Exp $
  * 
  * Copyright (C) 2000, 2001 by Martin Pool <mbp@samba.org>
  * 
@@ -24,7 +24,7 @@
 
 #include <stdio.h>
 
-#include "rsync.h"
+#include "librsync.h"
 
 
 /** \brief Library version string. */
